/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.1 Ganglinienprognose
 * Copyright (C) 2019 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.glprog.glprog.domain;

import java.time.Duration;

import de.bsvrz.iav.glprog.glprog.GanglinienAuswahlmethode;

/**
 * Repräsentation des Parameters GanglinienModellPrognose an einem
 * Messquerschnitt.
 * 
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class GanglinienModellPrognose {

    public static final GanglinienModellPrognose KEIN_PARAMETER = new GanglinienModellPrognose();

    public static GanglinienModellPrognose of(GanglinienAuswahlmethode auswahlMethode, Duration matchingHorizont,
            Duration matchingIntervall, Duration matchingOffset, int maximalerMatchingFehler) {
        return new GanglinienModellPrognose(auswahlMethode, matchingHorizont, matchingIntervall, matchingOffset,
                maximalerMatchingFehler);
    }

    private final GanglinienAuswahlmethode auswahlMethode;
    private final Duration matchingHorizont;
    private final Duration matchingIntervall;
    private final Duration matchingOffset;
    private final int maximalerMatchingFehler;

    private GanglinienModellPrognose() {
        auswahlMethode = GanglinienAuswahlmethode.UNDEFINIERT;
        matchingHorizont = Duration.ZERO;
        matchingIntervall = Duration.ZERO;
        matchingOffset = Duration.ZERO;
        maximalerMatchingFehler = 0;
    }

    private GanglinienModellPrognose(GanglinienAuswahlmethode auswahlMethode, Duration horizont,
            Duration matchingIntervall, Duration matchingOffset, int maximalerMatchingFehler) {
        this.auswahlMethode = auswahlMethode;
        this.matchingHorizont = horizont;
        this.matchingIntervall = matchingIntervall;
        this.matchingOffset = matchingOffset;
        this.maximalerMatchingFehler = maximalerMatchingFehler;
    }

    public GanglinienAuswahlmethode getAuswahlMethode() {
        return auswahlMethode;
    }

    public Duration getMatchingIntervall() {
        return matchingIntervall;
    }

    public int getMaxMatchingFehler() {
        return maximalerMatchingFehler;
    }

    public Duration getPatternMatchingHorizont() {
        return matchingHorizont;
    }

    public Duration getPatternMatchingOffset() {
        return matchingOffset;
    }

    public boolean isNull() {
        return auswahlMethode == GanglinienAuswahlmethode.UNDEFINIERT;
    }
}
