/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.1 Ganglinienprognose
 * Copyright (C) 2019 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.glprog.glprog.update;

import java.time.LocalTime;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.iav.gllib.gllib.portals.DavObjektFactory;
import de.bsvrz.iav.glprog.glprog.portals.DerbyGanglinienDatenbank;
import de.bsvrz.sys.funclib.application.StandardApplication;
import de.bsvrz.sys.funclib.application.StandardApplicationRunner;
import de.bsvrz.sys.funclib.commandLineArgs.ArgumentList;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Applikation zum Aktualisieren einer Gangliniendatenbank.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class GanglinienDbUpdater implements StandardApplication {

	private Debug logger;
	private String dbDir;

	@Override
	public void parseArguments(ArgumentList argumentList) throws Exception {
		logger = Debug.getLogger();
		dbDir = argumentList.fetchArgument("-dbVerzeichnis=gldb").asString();
	}

	@Override
	public void initialize(ClientDavInterface connection) throws Exception {
		DavObjektFactory objektFactory = new DavObjektFactory(connection);
		DerbyGanglinienDatenbank glDb = new DerbyGanglinienDatenbank(objektFactory, dbDir, LocalTime.MIDNIGHT);
		glDb.close();
		if (logger != null) {
			logger.info("Konvertierung abgeschlossen");
		}
		System.exit(0);
	}

	public static void main(String[] args) {
		StandardApplicationRunner.run(new GanglinienDbUpdater(), args);
	}

}
